@@ -553,6 +553,9 @@ on_delete (GSimpleAction *action,
                 et_application_window_file_area_set_sensitive (self, TRUE);
 
                 return; /*We stop all actions. */
+            default:
+                g_assert_not_reached ();
+                break;
         }
     }
 
@@ -735,11 +738,6 @@ on_select_all (GSimpleAction *action,
                                                  focused))
     /* Assume that other widgets should select all in the file view. */
     {
-        EtApplicationWindowPrivate *priv;
-        EtApplicationWindow *self = ET_APPLICATION_WINDOW (user_data);
-
-        priv = et_application_window_get_instance_private (self);
-
         /* Save the current displayed data */
         ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
 
@@ -877,7 +875,7 @@ on_remove_tags (GSimpleAction *action,
     {
         etfile = et_browser_get_et_file_from_path (ET_BROWSER (priv->browser),
                                                    l->data);
-        FileTag = ET_File_Tag_Item_New ();
+        FileTag = et_file_tag_new ();
         ET_Manage_Changes_Of_File_Data (etfile, NULL, FileTag);
 
         fraction = (++progress_bar_index) / (double) selectcount;
@@ -2342,7 +2340,7 @@ et_application_window_update_actions (EtApplicationWindow *self)
         set_action_state (self, "save-force", TRUE);
 
         /* Enable undo command if there are data into main undo list (history list) */
-        if (ET_History_File_List_Has_Undo_Data ())
+        if (et_history_list_has_undo (ETCore->ETHistoryFileList))
         {
             set_action_state (self, "undo-last-changes", TRUE);
         }
@@ -2352,7 +2350,7 @@ et_application_window_update_actions (EtApplicationWindow *self)
         }
 
         /* Enable redo commands if there are data into main redo list (history list) */
-        if (ET_History_File_List_Has_Redo_Data ())
+        if (et_history_list_has_redo (ETCore->ETHistoryFileList))
         {
             set_action_state (self, "redo-last-changes", TRUE);
         }
@@ -2628,18 +2626,6 @@ et_application_window_browser_refresh_file_in_list (EtApplicationWindow *self,
     et_browser_refresh_file_in_list (ET_BROWSER (priv->browser), file);
 }
 
-void
-et_application_window_browser_refresh_sort (EtApplicationWindow *self)
-{
-    EtApplicationWindowPrivate *priv;
-
-    g_return_if_fail (ET_APPLICATION_WINDOW (self));
-
-    priv = et_application_window_get_instance_private (self);
-
-    et_browser_refresh_sort (ET_BROWSER (priv->browser));
-}
-
 static void
 quit_confirmed (EtApplicationWindow *self)
 {
@@ -2676,7 +2662,7 @@ et_application_window_quit (EtApplicationWindow *self)
 
     /* Check if all files have been saved before exit */
     if (g_settings_get_boolean (MainSettings, "confirm-when-unsaved-files")
-        && ET_Check_If_All_Files_Are_Saved () != TRUE)
+        && et_file_list_check_all_saved (ETCore->ETFileList) != TRUE)
     {
         /* Some files haven't been saved */
         msgbox = gtk_message_dialog_new (GTK_WINDOW (self),
