@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014,2015  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -1109,7 +1109,9 @@ ET_Free_File_Tag_List (GList *FileTagList)
     for (l = FileTagList; l != NULL; l = g_list_next (l))
     {
         if ((File_Tag *)l->data)
-            ET_Free_File_Tag_Item ((File_Tag *)l->data);
+        {
+            et_file_tag_free ((File_Tag *)l->data);
+        }
     }
 
     g_list_free (FileTagList);
@@ -1197,7 +1199,7 @@ void
 ET_Display_File_Data_To_UI (ET_File *ETFile)
 {
     EtApplicationWindow *window;
-    const ET_File_Description *ETFileDescription;
+    const ET_File_Description *description;
     const gchar *cur_filename_utf8;
     gchar *msg;
     EtFileHeaderFields *fields;
@@ -1207,7 +1209,7 @@ ET_Display_File_Data_To_UI (ET_File *ETFile)
                       /* For the case where ETFile is an "empty" structure. */
 
     cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
-    ETFileDescription = ETFile->ETFileDescription;
+    description = ETFile->ETFileDescription;
 
     /* Save the current displayed file */
     ETCore->ETFileDisplayed = ETFile;
@@ -1227,7 +1229,7 @@ ET_Display_File_Data_To_UI (ET_File *ETFile)
     et_application_window_tag_area_display_controls (window, ETFile);
 
     /* Display file data, header data and file type */
-    switch (ETFileDescription->FileType)
+    switch (description->FileType)
     {
 #if defined ENABLE_MP3 && defined ENABLE_ID3LIB
         case MP3_FILE:
@@ -1289,6 +1291,7 @@ ET_Display_File_Data_To_UI (ET_File *ETFile)
             et_opus_file_header_fields_free (fields);
             break;
 #endif
+        case OFR_FILE:
         case UNKNOWN_FILE:
         default:
             /* Default displaying. */
@@ -1297,7 +1300,7 @@ ET_Display_File_Data_To_UI (ET_File *ETFile)
             et_file_header_fields_free (fields);
             Log_Print (LOG_ERROR,
                        "ETFileInfo: Undefined file type %d for file %s.",
-                       ETFileDescription->FileType, cur_filename_utf8);
+                       description->FileType, cur_filename_utf8);
             break;
     }
 
@@ -1325,7 +1328,11 @@ ET_Display_Filename_To_UI (const ET_File *ETFile)
                                                   dirname_utf8);
 
     // And refresh the number of files in this directory
-    text = g_strdup_printf(ngettext("One file","%u files",ET_Get_Number_Of_Files_In_Directory(dirname_utf8)),ET_Get_Number_Of_Files_In_Directory(dirname_utf8));
+    text = g_strdup_printf (ngettext ("One file", "%u files",
+                                      et_file_list_get_n_files_in_path (ETCore->ETFileList,
+                                                                        dirname_utf8)),
+                            et_file_list_get_n_files_in_path (ETCore->ETFileList,
+                                                              dirname_utf8));
     et_application_window_browser_label_set_text (ET_APPLICATION_WINDOW (MainWindow),
                                                   text);
     g_free(dirname_utf8);
@@ -1352,8 +1359,8 @@ ET_Display_File_Info_To_UI (const ET_File *ETFile)
     fields->description = _("File");
 
     /* MPEG, Layer versions */
-    fields->version = g_strdup_printf ("%d, Layer %d", info->version,
-                                       info->layer);
+    fields->version = g_strdup_printf ("%d, Layer %" G_GSIZE_FORMAT,
+                                       info->version, info->layer);
 
     /* Bitrate */
     fields->bitrate = g_strdup_printf (_("%d kb/s"), info->bitrate);
@@ -1392,7 +1399,7 @@ ET_Display_File_Info_To_UI (const ET_File *ETFile)
  */
 void ET_Save_File_Data_From_UI (ET_File *ETFile)
 {
-    const ET_File_Description *ETFileDescription;
+    const ET_File_Description *description;
     File_Name *FileName;
     File_Tag  *FileTag;
     guint      undo_key;
@@ -1402,7 +1409,7 @@ void ET_Save_File_Data_From_UI (ET_File *ETFile)
                       && ETFile->FileNameCur->data != NULL);
 
     cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
-    ETFileDescription = ETFile->ETFileDescription;
+    description = ETFile->ETFileDescription;
     undo_key = ET_Undo_Key_New();
 
 
@@ -1414,7 +1421,7 @@ void ET_Save_File_Data_From_UI (ET_File *ETFile)
     FileName->key = undo_key;
     ET_Save_File_Name_From_UI(ETFile,FileName); // Used for all files!
 
-    switch (ETFileDescription->TagType)
+    switch (description->TagType)
     {
 #ifdef ENABLE_MP3
         case ID3_TAG:
@@ -1436,12 +1443,14 @@ void ET_Save_File_Data_From_UI (ET_File *ETFile)
 #endif
         case APE_TAG:
             FileTag = et_application_window_tag_area_create_file_tag (ET_APPLICATION_WINDOW (MainWindow));
-            ET_Copy_File_Tag_Item_Other_Field (ETFile, FileTag);
+            et_file_tag_copy_other_into (ETFile->FileTag->data, FileTag);
             break;
         case UNKNOWN_TAG:
         default:
-            FileTag = ET_File_Tag_Item_New ();
-            Log_Print(LOG_ERROR,"FileTag: Undefined tag type %d for file %s.",ETFileDescription->TagType,cur_filename_utf8);
+            FileTag = et_file_tag_new ();
+            Log_Print (LOG_ERROR,
+                       "FileTag: Undefined tag type %d for file %s.",
+                       description->TagType, cur_filename_utf8);
             break;
     }
 
@@ -1824,7 +1833,7 @@ ET_Save_File_Tag_Internal (ET_File *ETFile, File_Tag *FileTag)
 gboolean
 ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
 {
-    const ET_File_Description *ETFileDescription;
+    const ET_File_Description *description;
     const gchar *cur_filename;
     const gchar *cur_filename_utf8;
     gboolean state;
@@ -1837,14 +1846,14 @@ ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
     cur_filename = ((File_Name *)(ETFile->FileNameCur)->data)->value;
     cur_filename_utf8 = ((File_Name *)(ETFile->FileNameCur)->data)->value_utf8;
 
-    ETFileDescription = ETFile->ETFileDescription;
+    description = ETFile->ETFileDescription;
 
     /* Store the file timestamps (in case they are to be preserved) */
     file = g_file_new_for_path (cur_filename);
     fileinfo = g_file_query_info (file, "time::*", G_FILE_QUERY_INFO_NONE,
                                   NULL, NULL);
 
-    switch (ETFileDescription->TagType)
+    switch (description->TagType)
     {
 #ifdef ENABLE_MP3
         case ID3_TAG:
@@ -1881,8 +1890,9 @@ ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
 #endif
         case UNKNOWN_TAG:
         default:
-            Log_Print(LOG_ERROR,"Saving to HD: Undefined function for tag type '%d' (file %s).",
-                ETFileDescription->TagType,cur_filename_utf8);
+            Log_Print (LOG_ERROR,
+                       "Saving to HD: Undefined function for tag type '%d' (file %s).",
+                       description->TagType, cur_filename_utf8);
             state = FALSE;
             break;
     }
@@ -1976,13 +1986,16 @@ ET_Manage_Changes_Of_File_Data (ET_File *ETFile,
      */
     if (FileTag)
     {
-        if ( ETFile->FileTag && ET_Detect_Changes_Of_File_Tag( (File_Tag *)(ETFile->FileTag)->data,FileTag )==TRUE )
+        if (ETFile->FileTag
+            && et_file_tag_detect_difference ((File_Tag *)(ETFile->FileTag)->data,
+                                              FileTag) == TRUE)
         {
             ET_Add_File_Tag_To_List(ETFile,FileTag);
             undo_added |= TRUE;
-        }else
+        }
+        else
         {
-            ET_Free_File_Tag_Item(FileTag);
+            et_file_tag_free (FileTag);
         }
     }
 
@@ -1990,7 +2003,10 @@ ET_Manage_Changes_Of_File_Data (ET_File *ETFile,
      * Generate main undo (file history of modifications)
      */
     if (undo_added)
-        ET_Add_File_To_History_List(ETFile);
+    {
+        ETCore->ETHistoryFileList = et_history_list_add (ETCore->ETHistoryFileList,
+                                                         ETFile);
+    }
 
     //return TRUE;
     return undo_added;
