@@ -62,18 +62,17 @@
 #endif
 
 /*
- * Frees the full main list of files: GList *ETFileList and reinitialize it.
+ * et_file_list_free:
+ * @file_list: (element-type ET_File) (allow-none): a list of files
+ *
+ * Frees the full list of files.
  */
-gboolean
-ET_Free_File_List (void)
+void
+et_file_list_free (GList *file_list)
 {
-    g_return_val_if_fail (ETCore != NULL && ETCore->ETFileList != NULL, FALSE);
+    g_return_if_fail (file_list != NULL);
 
-    g_list_free_full (ETCore->ETFileList,
-                      (GDestroyNotify)ET_Free_File_List_Item);
-    ETCore->ETFileList = NULL;
-
-    return TRUE;
+    g_list_free_full (file_list, (GDestroyNotify)ET_Free_File_List_Item);
 }
 
 static void
@@ -85,53 +84,38 @@ et_history_file_free (ET_History_File *file)
 /*
  * History list contains only pointers, so no data to free except the history structure.
  */
-gboolean
-ET_Free_History_File_List (void)
+void
+et_history_file_list_free (GList *file_list)
 {
-    g_return_val_if_fail (ETCore != NULL && ETCore->ETHistoryFileList != NULL,
-                          FALSE);
+    g_return_if_fail (file_list != NULL);
 
-    ETCore->ETHistoryFileList = g_list_first (ETCore->ETHistoryFileList);
-
-    g_list_free_full (ETCore->ETHistoryFileList,
-                      (GDestroyNotify)et_history_file_free);
-
-    ETCore->ETHistoryFileList = NULL;
-
-    return TRUE;
+    g_list_free_full (file_list, (GDestroyNotify)et_history_file_free);
 }
 
 /*
  * "Display" list contains only pointers, so NOTHING to free
  */
-gboolean
-ET_Free_Displayed_File_List (void)
+void
+et_displayed_file_list_free (GList *file_list)
 {
-    g_return_val_if_fail (ETCore != NULL
-                          && ETCore->ETFileDisplayedList != NULL, FALSE);
-
-    ETCore->ETFileDisplayedList = NULL;
-
-    return TRUE;
 }
 
 /*
  * ArtistAlbum list contains 3 levels of lists
  */
-gboolean
-ET_Free_Artist_Album_File_List (void)
+void
+et_artist_album_file_list_free (GList *file_list)
 {
     GList *l;
 
-    g_return_val_if_fail (ETCore != NULL
-                          && ETCore->ETArtistAlbumFileList != NULL, FALSE);
+    g_return_if_fail (file_list != NULL);
 
     /* Pointers are stored inside the artist/album list-stores, so free them
      * first. */
     et_application_window_browser_clear_artist_model (ET_APPLICATION_WINDOW (MainWindow));
     et_application_window_browser_clear_album_model (ET_APPLICATION_WINDOW (MainWindow));
 
-    for (l = ETCore->ETArtistAlbumFileList; l != NULL; l = g_list_next (l))
+    for (l = file_list; l != NULL; l = g_list_next (l))
     {
         GList *m;
 
@@ -146,12 +130,7 @@ ET_Free_Artist_Album_File_List (void)
             g_list_free ((GList *)l->data);
     }
 
-    if (ETCore->ETArtistAlbumFileList)
-        g_list_free(ETCore->ETArtistAlbumFileList);
-
-    ETCore->ETArtistAlbumFileList = NULL;
-
-    return TRUE;
+    g_list_free (file_list);
 }
 
 /* Key for each item of ETFileList */
@@ -206,13 +185,17 @@ et_core_read_file_info (GFile *file,
 }
 
 /*
- * ET_Add_File_To_File_List: Add a file to the "main" list. And get all information of the file.
- * The filename passed in should be in raw format, only convert it to UTF8 when displaying it.
+ * et_file_list_add:
+ * Add a file to the "main" list. And get all information of the file.
+ * The filename passed in should be in raw format, only convert it to UTF8 when
+ * displaying it.
  */
 GList *
-ET_Add_File_To_File_List (gchar *filename)
+et_file_list_add (GList *file_list,
+                  gchar *filename)
 {
-    const ET_File_Description *ETFileDescription;
+    GList *result;
+    const ET_File_Description *description;
     ET_File      *ETFile;
     File_Name    *FileName;
     File_Tag     *FileTag;
@@ -227,8 +210,7 @@ ET_Add_File_To_File_List (gchar *filename)
     GError *error = NULL;
     gboolean success;
 
-    if (!filename)
-        return ETCore->ETFileList;
+    g_return_val_if_fail (filename != NULL, file_list);
 
     file = g_file_new_for_path (filename);
 
@@ -236,7 +218,7 @@ ET_Add_File_To_File_List (gchar *filename)
     ETFileKey = ET_File_Key_New();
 
     /* Get description of the file */
-    ETFileDescription = ET_Get_File_Description(filename);
+    description = ET_Get_File_Description (filename);
 
     /* Get real extension of the file (keeping the case) */
     ETFileExtension = g_strdup(ET_Get_File_Extension(filename));
@@ -249,7 +231,7 @@ ET_Add_File_To_File_List (gchar *filename)
     FileName->value_ck   = g_utf8_collate_key_for_filename(filename_utf8, -1);
 
     /* Fill the File_Tag structure for FileTagList */
-    FileTag = ET_File_Tag_Item_New();
+    FileTag = et_file_tag_new ();
     FileTag->saved = TRUE;    /* The file hasn't been changed, so it's saved */
 
     /* Patch from Doruk Fisek and Onur Kucuk: avoid upper/lower conversion bugs
@@ -258,7 +240,7 @@ ET_Add_File_To_File_List (gchar *filename)
      * it is written as 'Title=' in the file */
     setlocale(LC_CTYPE, "C");
 
-    switch (ETFileDescription->TagType)
+    switch (description->TagType)
     {
 #ifdef ENABLE_MP3
         case ID3_TAG:
@@ -338,7 +320,9 @@ ET_Add_File_To_File_List (gchar *filename)
         case UNKNOWN_TAG:
         default:
             /* FIXME: Translatable string. */
-            Log_Print(LOG_ERROR,"FileTag: Undefined tag type (%d) for file %s",ETFileDescription->TagType,filename_utf8);
+            Log_Print (LOG_ERROR,
+                       "FileTag: Undefined tag type (%d) for file %s",
+                       description->TagType, filename_utf8);
             break;
     }
 
@@ -352,7 +336,7 @@ ET_Add_File_To_File_List (gchar *filename)
     /* Fill the ET_File_Info structure */
     ETFileInfo = ET_File_Info_Item_New ();
 
-    switch (ETFileDescription->FileType)
+    switch (description->FileType)
     {
 #if defined ENABLE_MP3 && defined ENABLE_ID3LIB
         case MP3_FILE:
@@ -398,10 +382,13 @@ ET_Add_File_To_File_List (gchar *filename)
             success = et_opus_read_file_info (file, ETFileInfo, &error);
             break;
 #endif
+        case OFR_FILE:
         case UNKNOWN_FILE:
         default:
             /* FIXME: Translatable string. */
-            Log_Print(LOG_ERROR,"ETFileInfo: Undefined file type (%d) for file %s",ETFileDescription->FileType,filename_utf8);
+            Log_Print (LOG_ERROR,
+                       "ETFileInfo: Undefined file type (%d) for file %s",
+                       description->FileType, filename_utf8);
             /* To get at least the file size. */
             success = et_core_read_file_info (file, ETFileInfo, &error);
             break;
@@ -440,7 +427,7 @@ ET_Add_File_To_File_List (gchar *filename)
 
     ETFile->IndexKey             = 0; // Will be renumered after...
     ETFile->ETFileKey            = ETFileKey;
-    ETFile->ETFileDescription    = ETFileDescription;
+    ETFile->ETFileDescription    = description;
     ETFile->ETFileExtension      = ETFileExtension;
     ETFile->FileNameList         = g_list_append(NULL,FileName);
     ETFile->FileNameCur          = ETFile->FileNameList;
@@ -450,7 +437,7 @@ ET_Add_File_To_File_List (gchar *filename)
     ETFile->ETFileInfo           = ETFileInfo;
 
     /* Add the item to the "main list" */
-    ETCore->ETFileList = g_list_append(ETCore->ETFileList,ETFile);
+    result = g_list_append (file_list, ETFile);
 
 
     /*
@@ -463,7 +450,7 @@ ET_Add_File_To_File_List (gchar *filename)
     FileName->key = undo_key;
     ET_Save_File_Name_Internal(ETFile,FileName);
 
-    FileTag = ET_File_Tag_Item_New();
+    FileTag = et_file_tag_new ();
     FileTag->key = undo_key;
     ET_Save_File_Tag_Internal(ETFile,FileTag);
 
@@ -488,7 +475,7 @@ ET_Add_File_To_File_List (gchar *filename)
     //ET_Add_File_To_Artist_Album_File_List(ETFile);
 
     //ET_Debug_Print_File_List(ETCore->ETFileList,__FILE__,__LINE__,__FUNCTION__);
-    return ETCore->ETFileList;
+    return result;
 }
 
 /*
@@ -573,8 +560,9 @@ ET_Comp_Func_Sort_Etfile_Item_By_Ascending_Filename (const ET_File *ETFile1,
  *  - "AlbumList" list is a list of ETFile items.
  * Note : use the function ET_Debug_Print_Artist_Album_List(...) to understand how it works, it needed...
  */
-static gboolean
-ET_Add_File_To_Artist_Album_File_List (ET_File *ETFile)
+static GList *
+et_artist_album_list_add_file (GList *file_list,
+                               ET_File *ETFile)
 {
     const gchar *ETFile_Artist;
     const gchar *ETFile_Album;
@@ -583,16 +571,17 @@ ET_Add_File_To_Artist_Album_File_List (ET_File *ETFile)
     GList *ArtistList;
     GList *AlbumList = NULL;
     GList *etfilelist = NULL;
+    GList *result;
     ET_File *etfile = NULL;
 
-    g_return_val_if_fail (ETFile != NULL, FALSE);
+    g_return_if_fail (ETFile != NULL);
 
     /* Album value of the ETFile passed in parameter. */
     ETFile_Album = ((File_Tag *)ETFile->FileTag->data)->album;
     /* Artist value of the ETFile passed in parameter. */
     ETFile_Artist = ((File_Tag *)ETFile->FileTag->data)->artist;
 
-    for (ArtistList = ETCore->ETArtistAlbumFileList; ArtistList != NULL;
+    for (ArtistList = file_list; ArtistList != NULL;
          ArtistList = g_list_next (ArtistList))
     {
         AlbumList = (GList *)ArtistList->data;  /* Take the first item */
@@ -637,7 +626,7 @@ ET_Add_File_To_Artist_Album_File_List (ET_File *ETFile)
                                                      ETFile);
                     AlbumList->data = g_list_sort ((GList *)AlbumList->data,
                                                    (GCompareFunc)ET_Comp_Func_Sort_Etfile_Item_By_Ascending_Filename);
-                    return TRUE;
+                    return file_list;
                 }
 
                 AlbumList = g_list_next (AlbumList);
@@ -650,7 +639,7 @@ ET_Add_File_To_Artist_Album_File_List (ET_File *ETFile)
                                               etfilelist);
             ArtistList->data = g_list_sort ((GList *)ArtistList->data,
                                             (GCompareFunc)ET_Comp_Func_Sort_Album_Item_By_Ascending_Album);
-            return TRUE;
+            return file_list;
         }
     }
 
@@ -658,31 +647,29 @@ ET_Add_File_To_Artist_Album_File_List (ET_File *ETFile)
      * main list (=ETArtistAlbumFileList). */
     etfilelist = g_list_append (NULL, ETFile);
     AlbumList  = g_list_append (NULL, etfilelist);
-    ETCore->ETArtistAlbumFileList = g_list_append (ETCore->ETArtistAlbumFileList,
-                                                   AlbumList);
+    file_list = g_list_append (file_list, AlbumList);
 
     /* Sort the list by ascending Artist. */
-    ETCore->ETArtistAlbumFileList = g_list_sort (ETCore->ETArtistAlbumFileList,
-                                                 (GCompareFunc)ET_Comp_Func_Sort_Artist_Item_By_Ascending_Artist);
+    /* TODO: Use g_list_insert_sorted() instead. */
+    result = g_list_sort (file_list,
+                          (GCompareFunc)ET_Comp_Func_Sort_Artist_Item_By_Ascending_Artist);
 
-    return TRUE;
+    return result;
 }
 
-gboolean
-ET_Create_Artist_Album_File_List (void)
+GList *
+et_artist_album_list_new_from_file_list (GList *file_list)
 {
+    GList *result = NULL;
     GList *l;
 
-    if (ETCore->ETArtistAlbumFileList)
-        ET_Free_Artist_Album_File_List();
-
-    for (l = g_list_first (ETCore->ETFileList); l != NULL; l = g_list_next (l))
+    for (l = g_list_first (file_list); l != NULL; l = g_list_next (l))
     {
         ET_File *ETFile = (ET_File *)l->data;
-        ET_Add_File_To_Artist_Album_File_List(ETFile);
+        result = et_artist_album_list_add_file (result, ETFile);
     }
-    //ET_Debug_Print_Artist_Album_List(__FILE__,__LINE__,__FUNCTION__);
-    return TRUE;
+
+    return result;
 }
 
 /*
@@ -749,26 +736,24 @@ ET_Remove_File_From_Artist_Album_List (ET_File *ETFile)
  * Returns the length of the list of displayed files
  */
 static guint
-ET_Displayed_File_List_Get_Length (void)
+et_displayed_file_list_length (GList *displayed_list)
 {
-    GList *list = NULL;
+    GList *list;
 
-    list = g_list_first(ETCore->ETFileDisplayedList);
-    ETCore->ETFileDisplayedList_Length = g_list_length(list);
-    return ETCore->ETFileDisplayedList_Length;
+    list = g_list_first (displayed_list);
+    return g_list_length (list);;
 }
 
 /*
  * Renumber the list of displayed files (IndexKey) from 1 to n
  */
 static void
-ET_Displayed_File_List_Number (void)
+et_displayed_file_list_renumber (GList *displayed_list)
 {
     GList *l = NULL;
     guint i = 1;
 
-    for (l = g_list_first (ETCore->ETFileDisplayedList); l != NULL;
-         l = g_list_next (l))
+    for (l = g_list_first (displayed_list); l != NULL; l = g_list_next (l))
     {
         ((ET_File *)l->data)->IndexKey = i++;
     }
@@ -777,7 +762,7 @@ ET_Displayed_File_List_Number (void)
 /*
  * Delete the corresponding file and free the allocated data. Return TRUE if deleted.
  */
-gboolean
+void
 ET_Remove_File_From_File_List (ET_File *ETFile)
 {
     GList *ETFileList = NULL;          // Item containing the ETFile to delete... (in ETCore->ETFileList)
@@ -828,11 +813,11 @@ ET_Remove_File_From_File_List (ET_File *ETFile)
     if (ETFileDisplayedList)
         g_list_free(ETFileDisplayedList);
 
-    // Recalculate length of ETFileDisplayedList list
-    ET_Displayed_File_List_Get_Length();
+    /* Recalculate length of ETFileDisplayedList list. */
+    ETCore->ETFileDisplayedList_Length = et_displayed_file_list_length (ETCore->ETFileDisplayedList);
 
-    // To number the ETFile in the list
-    ET_Displayed_File_List_Number();
+    /* To number the ETFile in the list. */
+    et_displayed_file_list_renumber (ETCore->ETFileDisplayedList);
 
     // Displaying...
     if (ETCore->ETFileDisplayedList)
@@ -852,25 +837,12 @@ ET_Remove_File_From_File_List (ET_File *ETFile)
         et_application_window_tag_area_clear (ET_APPLICATION_WINDOW (MainWindow));
         et_application_window_update_actions (ET_APPLICATION_WINDOW (MainWindow));
     }
-
-    return TRUE;
 }
 
 /**************************
  * File sorting functions *
  **************************/
 
-/*
- * Sort the 'ETFileDisplayedList' following the 'Sorting_Type'
- * Note : Add also new sorting in 'Browser_List_Sort_Func'
- */
-void
-ET_Sort_Displayed_File_List (EtSortMode Sorting_Type)
-{
-    ETCore->ETFileDisplayedList = ET_Sort_File_List(ETCore->ETFileDisplayedList,Sorting_Type);
-}
-
-
 /*
  * Set appropriate sort order for the given column_id
  */
@@ -1077,6 +1049,9 @@ ET_Sort_File_List (GList *ETFileList,
         case ET_SORT_MODE_DESCENDING_FILE_SAMPLERATE:
             etfilelist = g_list_sort(etfilelist,(GCompareFunc)ET_Comp_Func_Sort_File_By_Descending_File_Samplerate);
             break;
+        default:
+            g_assert_not_reached ();
+            break;
     }
     /* Save sorting mode (note: needed when called from UI). */
     g_settings_set_enum (MainSettings, "sort-mode", Sorting_Type);
@@ -1085,33 +1060,6 @@ ET_Sort_File_List (GList *ETFileList,
     return etfilelist;
 }
 
-/*
- * Sort the list of files following the 'Sorting_Type' value. The new sorting is displayed in the UI.
- */
-void
-ET_Sort_Displayed_File_List_And_Update_UI (EtSortMode Sorting_Type)
-{
-    g_return_if_fail (ETCore->ETFileList != NULL);
-
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
-
-    /* Sort the list */
-    ET_Sort_Displayed_File_List(Sorting_Type);
-
-    /* To number the ETFile in the list */
-    ET_Displayed_File_List_Number();
-
-    /* Reload files in browser list */
-    ET_Displayed_File_List_By_Etfile(ETCore->ETFileDisplayed);  // Just to update 'ETFileDisplayedList'
-    et_application_window_browser_select_file_by_et_file (ET_APPLICATION_WINDOW (MainWindow),
-                                                          ETCore->ETFileDisplayed,
-                                                          TRUE);
-    ET_Display_File_Data_To_UI(ETCore->ETFileDisplayed);
-
-    et_application_window_browser_refresh_sort (ET_APPLICATION_WINDOW (MainWindow));
-    et_application_window_update_actions (ET_APPLICATION_WINDOW (MainWindow));
-}
-
 /*
  * Returns the first item of the "displayed list"
  */
@@ -1194,15 +1142,14 @@ ET_Displayed_File_List_By_Etfile (const ET_File *ETFile)
  * Load the list of displayed files (calculate length, size, ...)
  * It contains part (filtrated : view by artists and albums) or full ETCore->ETFileList list
  */
-gboolean
-ET_Set_Displayed_File_List (GList *ETFileList)
+void
+et_displayed_file_list_set (GList *ETFileList)
 {
     GList *l = NULL;
 
     ETCore->ETFileDisplayedList = g_list_first(ETFileList);
 
-    //ETCore->ETFileDisplayedListPtr = ETCore->ETFileDisplayedList;
-    ETCore->ETFileDisplayedList_Length = ET_Displayed_File_List_Get_Length();
+    ETCore->ETFileDisplayedList_Length = et_displayed_file_list_length (ETCore->ETFileDisplayedList);
     ETCore->ETFileDisplayedList_TotalSize     = 0;
     ETCore->ETFileDisplayedList_TotalDuration = 0;
 
@@ -1214,13 +1161,12 @@ ET_Set_Displayed_File_List (GList *ETFileList)
     }
 
     /* Sort the file list. */
-    ET_Sort_Displayed_File_List (g_settings_get_enum (MainSettings,
-                                 "sort-mode"));
+    ET_Sort_File_List (ETCore->ETFileDisplayedList,
+                       g_settings_get_enum (MainSettings,
+                                            "sort-mode"));
 
-    // Should renums ETCore->ETFileDisplayedList only!
-    ET_Displayed_File_List_Number();
-
-    return TRUE;
+    /* Should renums ETCore->ETFileDisplayedList only! */
+    et_displayed_file_list_renumber (ETCore->ETFileDisplayedList);
 }
 
 /*
@@ -1228,26 +1174,32 @@ ET_Set_Displayed_File_List (GList *ETFileList)
  * (for ex: "/mp3/old_path/file.mp3" to "/mp3/new_path/file.mp3"
  */
 void
-ET_Update_Directory_Name_Into_File_List (const gchar *last_path,
-                                         const gchar *new_path)
+et_file_list_update_directory_name (GList *file_list,
+                                    const gchar *old_path,
+                                    const gchar *new_path)
 {
     GList *filelist;
     ET_File *file;
     GList *filenamelist;
     gchar *filename;
-    gchar *last_path_tmp;
+    gchar *old_path_tmp;
 
-    if (!ETCore->ETFileList || !last_path || !new_path ||
-        strlen(last_path) < 1 || strlen(new_path) < 1 )
-        return;
+    g_return_if_fail (file_list != NULL);
+    g_return_if_fail (old_path != NULL && *old_path != '\0');
+    g_return_if_fail (new_path != NULL && *new_path != '\0');
 
-    // Add '/' to end of path to avoid ambiguity between a directory and a filename...
-    if (last_path[strlen(last_path)-1]==G_DIR_SEPARATOR)
-        last_path_tmp = g_strdup(last_path);
+    /* Add '/' to end of path to avoid ambiguity between a directory and a
+     * filename... */
+    if (old_path[strlen (old_path) - 1] == G_DIR_SEPARATOR)
+    {
+        old_path_tmp = g_strdup (old_path);
+    }
     else
-        last_path_tmp = g_strconcat(last_path,G_DIR_SEPARATOR_S,NULL);
+    {
+        old_path_tmp = g_strconcat (old_path, G_DIR_SEPARATOR_S, NULL);
+    }
 
-    for (filelist = g_list_first (ETCore->ETFileList); filelist != NULL;
+    for (filelist = g_list_first (file_list); filelist != NULL;
          filelist = g_list_next (filelist))
     {
         if ((file = filelist->data))
@@ -1259,32 +1211,33 @@ ET_Update_Directory_Name_Into_File_List (const gchar *last_path,
 
                 if ( FileName && (filename=FileName->value) )
                 {
-                    // Replace path of filename
-                    if ( strncmp(filename,last_path_tmp,strlen(last_path_tmp))==0 )
+                    /* Replace path of filename. */
+                    if (strncmp (filename, old_path_tmp, strlen (old_path_tmp))
+                        == 0)
                     {
                         gchar *filename_tmp;
 
                         // Create the new filename
-                        filename_tmp = g_strconcat(new_path,
-                                                   (new_path[strlen(new_path)-1]==G_DIR_SEPARATOR) ? "" : G_DIR_SEPARATOR_S,
-                                                   &filename[strlen(last_path_tmp)],NULL);
+                        filename_tmp = g_strconcat (new_path,
+                                                    (new_path[strlen (new_path) - 1] == G_DIR_SEPARATOR) ? "" : G_DIR_SEPARATOR_S,
+                                                    &filename[strlen (old_path_tmp)],NULL);
 
                         /* Replace the filename (in file system encoding). */
-                        g_free(FileName->value);
+                        g_free (FileName->value);
                         FileName->value = filename_tmp;
                         /* Replace the filename (in file system encoding). */
-                        g_free(FileName->value_utf8);
-                        FileName->value_utf8 = filename_to_display(FileName->value);
-                        // Recalculate the collate key
-                        g_free(FileName->value_ck);
-                        FileName->value_ck = g_utf8_collate_key_for_filename(FileName->value_utf8, -1);
+                        g_free (FileName->value_utf8);
+                        FileName->value_utf8 = filename_to_display (FileName->value);
+                        /* Recalculate the collate key. */
+                        g_free (FileName->value_ck);
+                        FileName->value_ck = g_utf8_collate_key_for_filename (FileName->value_utf8, -1);
                     }
                 }
              }
         }
     }
 
-    g_free(last_path_tmp);
+    g_free (old_path_tmp);
 }
 
 /*
@@ -1297,8 +1250,8 @@ ET_Undo_History_File_Data (void)
     ET_File *ETFile;
     const ET_History_File *ETHistoryFile;
 
-    g_return_val_if_fail (ETCore->ETHistoryFileList != NULL ||
-                          ET_History_File_List_Has_Undo_Data (), NULL);
+    g_return_val_if_fail (ETCore->ETHistoryFileList != NULL, NULL);
+    g_return_val_if_fail (et_history_list_has_undo (ETCore->ETHistoryFileList), NULL);
 
     ETHistoryFile = (ET_History_File *)ETCore->ETHistoryFileList->data;
     ETFile        = (ET_File *)ETHistoryFile->ETFile;
@@ -1311,15 +1264,15 @@ ET_Undo_History_File_Data (void)
 }
 
 /*
- * Returns TRUE if undo file list contains undo data
+ * et_history_list_has_undo:
+ * @history_list: the end of a history list
+ *
+ * Returns: %TRUE if undo file list contains undo data, %FALSE otherwise
  */
 gboolean
-ET_History_File_List_Has_Undo_Data (void)
+et_history_list_has_undo (GList *history_list)
 {
-    if (ETCore->ETHistoryFileList && ETCore->ETHistoryFileList->prev)
-        return TRUE;
-    else
-        return FALSE;
+    return history_list && history_list->prev;
 }
 
 
@@ -1332,7 +1285,11 @@ ET_Redo_History_File_Data (void)
     ET_File *ETFile;
     ET_History_File *ETHistoryFile;
 
-    if (!ETCore->ETHistoryFileList || !ET_History_File_List_Has_Redo_Data()) return NULL;
+    if (!ETCore->ETHistoryFileList
+        || !et_history_list_has_redo (ETCore->ETHistoryFileList))
+    {
+        return NULL;
+    }
 
     ETHistoryFile = (ET_History_File *)ETCore->ETHistoryFileList->next->data;
     ETFile        = (ET_File *)ETHistoryFile->ETFile;
@@ -1344,25 +1301,27 @@ ET_Redo_History_File_Data (void)
     return ETFile;
 }
 
-
 /*
- * Returns TRUE if undo file list contains redo data
+ * et_history_list_has_redo:
+ * @history_list: the end of a history list
+ *
+ * Returns: %TRUE if undo file list contains redo data, %FALSE otherwise
  */
-gboolean ET_History_File_List_Has_Redo_Data (void)
+gboolean
+et_history_list_has_redo (GList *history_list)
 {
-    if (ETCore->ETHistoryFileList && ETCore->ETHistoryFileList->next)
-        return TRUE;
-    else
-        return FALSE;
+    return history_list && history_list->next;
 }
 
 /*
-* - * Add a ETFile item to the main undo list of files
-*   - */
-gboolean
-ET_Add_File_To_History_List (ET_File *ETFile)
+ * Add a ETFile item to the main undo list of files
+ */
+GList *
+et_history_list_add (GList *history_list,
+                     ET_File *ETFile)
 {
     ET_History_File *ETHistoryFile;
+    GList *result;
 
     g_return_val_if_fail (ETFile != NULL, FALSE);
 
@@ -1370,40 +1329,51 @@ ET_Add_File_To_History_List (ET_File *ETFile)
     ETHistoryFile->ETFile = ETFile;
 
     /* The undo list must contains one item before the 'first undo' data */
-    if (!ETCore->ETHistoryFileList)
+    if (!history_list)
     {
-        ETCore->ETHistoryFileList = g_list_append (ETCore->ETHistoryFileList,
-                                                   g_slice_new0 (ET_History_File));
+        result = g_list_append (NULL,
+                                g_slice_new0 (ET_History_File));
+    }
+    else
+    {
+        result = history_list;
     }
 
     /* Add the item to the list (cut end of list from the current element) */
-    ETCore->ETHistoryFileList = g_list_append(ETCore->ETHistoryFileList,ETHistoryFile);
-    ETCore->ETHistoryFileList = g_list_last(ETCore->ETHistoryFileList);
+    result = g_list_append (result, ETHistoryFile);
+    /* TODO: Investigate whether this is sensible. */
+    result = g_list_last (result);
 
-    return TRUE;
+    return result;
 }
+
 /*
- * Ckecks if some files, in the list, had been changed but not saved.
- * Returns TRUE if all files have been saved.
- * Returns FALSE if some changes haven't been saved.
+ * et_file_list_check_all_saved:
+ * @etfilelist: (element-type ET_File) (allow-none): a list of files
+ *
+ * Checks if some files, in the list, have been changed but not saved.
+ *
+ * Returns: %TRUE if all files have been saved, %FALSE otherwise
  */
 gboolean
-ET_Check_If_All_Files_Are_Saved (void)
+et_file_list_check_all_saved (GList *etfilelist)
 {
-    /* Check if some files haven't been saved, if didn't nochange=0 */
-    if (!ETCore->ETFileList)
+    if (!etfilelist)
     {
         return TRUE;
-    }else
+    }
+    else
     {
         GList *l;
 
-        for (l = g_list_first (ETCore->ETFileList); l != NULL;
-             l = g_list_next (l))
+        for (l = g_list_first (etfilelist); l != NULL; l = g_list_next (l))
         {
-            if (ET_Check_If_File_Is_Saved ((ET_File *)l->data) == FALSE)
+            if (!ET_Check_If_File_Is_Saved ((ET_File *)l->data))
+            {
                 return FALSE;
+            }
         }
+
         return TRUE;
     }
 }
@@ -1413,7 +1383,8 @@ ET_Check_If_All_Files_Are_Saved (void)
  * Parameter "path" should be in UTF-8
  */
 guint
-ET_Get_Number_Of_Files_In_Directory (const gchar *path_utf8)
+et_file_list_get_n_files_in_path (GList *file_list,
+                                  const gchar *path_utf8)
 {
     gchar *path_key;
     GList *l;
@@ -1423,7 +1394,7 @@ ET_Get_Number_Of_Files_In_Directory (const gchar *path_utf8)
 
     path_key = g_utf8_collate_key (path_utf8, -1);
 
-    for (l = g_list_first (ETCore->ETFileList); l != NULL; l = g_list_next (l))
+    for (l = g_list_first (file_list); l != NULL; l = g_list_next (l))
     {
         ET_File *ETFile = (ET_File *)l->data;
         const gchar *cur_filename_utf8 = ((File_Name *)((GList *)ETFile->FileNameCur)->data)->value_utf8;
