@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014,2015  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -18,67 +18,39 @@
 
 #include "file_tag.h"
 
-#include "et_core.h"
-
-static void
-ET_Initialize_File_Tag_Item (File_Tag *FileTag)
-{
-    if (FileTag)
-    {
-        FileTag->key         = ET_Undo_Key_New();
-        FileTag->saved       = FALSE;
-        FileTag->title       = NULL;
-        FileTag->artist      = NULL;
-        FileTag->album_artist= NULL;
-        FileTag->album       = NULL;
-        FileTag->disc_number = NULL;
-        FileTag->disc_total = NULL;
-        FileTag->track       = NULL;
-        FileTag->track_total = NULL;
-        FileTag->year        = NULL;
-        FileTag->genre       = NULL;
-        FileTag->comment     = NULL;
-        FileTag->composer    = NULL;
-        FileTag->orig_artist = NULL;
-        FileTag->copyright   = NULL;
-        FileTag->url         = NULL;
-        FileTag->encoded_by  = NULL;
-        FileTag->picture     = NULL;
-        FileTag->other       = NULL;
-    }
-}
+#include "file.h"
 
 /*
- * Create a new File_Tag structure
+ * Create a new File_Tag structure.
  */
-File_Tag *ET_File_Tag_Item_New (void)
+File_Tag *
+et_file_tag_new (void)
 {
-    File_Tag *FileTag;
+    File_Tag *file_tag;
 
-    FileTag = g_slice_new (File_Tag);
-    ET_Initialize_File_Tag_Item (FileTag);
+    file_tag = g_slice_new0 (File_Tag);
+    file_tag->key = ET_Undo_Key_New ();
 
-    return FileTag;
+    return file_tag;
 }
 
 /*
  * Frees the list of 'other' field in a File_Tag item (contains attached gchar data).
  */
-static gboolean
-ET_Free_File_Tag_Item_Other_Field (File_Tag *FileTag)
+static void
+et_file_tag_free_other_field (File_Tag *file_tag)
 {
-    g_list_free_full (FileTag->other, g_free);
-
-    return TRUE;
+    g_list_free_full (file_tag->other, g_free);
 }
 
 
 /*
  * Frees a File_Tag item.
  */
-gboolean ET_Free_File_Tag_Item (File_Tag *FileTag)
+void
+et_file_tag_free (File_Tag *FileTag)
 {
-    g_return_val_if_fail (FileTag != NULL, FALSE);
+    g_return_if_fail (FileTag != NULL);
 
     g_free(FileTag->title);
     g_free(FileTag->artist);
@@ -97,32 +69,27 @@ gboolean ET_Free_File_Tag_Item (File_Tag *FileTag)
     g_free(FileTag->url);
     g_free(FileTag->encoded_by);
     et_file_tag_set_picture (FileTag, NULL);
-    // Free list of other fields
-    ET_Free_File_Tag_Item_Other_Field(FileTag);
+    et_file_tag_free_other_field (FileTag);
 
     g_slice_free (File_Tag, FileTag);
-    return TRUE;
 }
 
 /*
  * Duplicate the 'other' list
  */
 void
-ET_Copy_File_Tag_Item_Other_Field (const ET_File *ETFile,
-                                   File_Tag *FileTag)
+et_file_tag_copy_other_into (File_Tag *destination,
+                             const File_Tag *source)
 {
-    const File_Tag *FileTagCur;
     GList *l;
 
-    FileTagCur = (File_Tag *)(ETFile->FileTag)->data;
-
-    for (l = FileTagCur->other; l != NULL; l = g_list_next (l))
+    for (l = source->other; l != NULL; l = g_list_next (l))
     {
-        FileTag->other = g_list_prepend (FileTag->other,
-                                         g_strdup ((gchar *)l->data));
+        destination->other = g_list_prepend (destination->other,
+                                             g_strdup ((gchar *)l->data));
     }
 
-    FileTag->other = g_list_reverse (FileTag->other);
+    destination->other = g_list_reverse (destination->other);
 }
 
 
@@ -130,176 +97,42 @@ ET_Copy_File_Tag_Item_Other_Field (const ET_File *ETFile,
  * Copy data of the File_Tag structure (of ETFile) to the FileTag item.
  * Reallocate data if not null.
  */
-gboolean
-ET_Copy_File_Tag_Item (const ET_File *ETFile, File_Tag *FileTag)
+void
+et_file_tag_copy_into (File_Tag *destination,
+                       const File_Tag *source)
 {
-    const File_Tag *FileTagCur;
+    g_return_if_fail (source != NULL);
+    g_return_if_fail (destination != NULL);
 
-    g_return_val_if_fail (ETFile != NULL && ETFile->FileTag != NULL &&
-                          (File_Tag *)(ETFile->FileTag)->data != NULL, FALSE);
-    g_return_val_if_fail (FileTag != NULL, FALSE);
+    /* Key for the item, may be overwritten. */
+    destination->key = ET_Undo_Key_New ();
 
-    /* The data to duplicate to FileTag */
-    FileTagCur = (File_Tag *)(ETFile->FileTag)->data;
-    // Key for the item, may be overwritten
-    FileTag->key = ET_Undo_Key_New();
+    et_file_tag_set_title (destination, source->title);
+    et_file_tag_set_artist (destination, source->artist);
+    et_file_tag_set_album_artist (destination, source->album_artist);
+    et_file_tag_set_album (destination, source->album);
+    et_file_tag_set_disc_number (destination, source->disc_number);
+    et_file_tag_set_disc_total (destination, source->disc_total);
+    et_file_tag_set_year (destination, source->year);
+    et_file_tag_set_track_number (destination, source->track);
+    et_file_tag_set_track_total (destination, source->track_total);
+    et_file_tag_set_genre (destination, source->genre);
+    et_file_tag_set_comment (destination, source->comment);
+    et_file_tag_set_composer (destination, source->composer);
+    et_file_tag_set_orig_artist (destination, source->orig_artist);
+    et_file_tag_set_copyright (destination, source->copyright);
+    et_file_tag_set_url (destination, source->url);
+    et_file_tag_set_encoded_by (destination, source->encoded_by);
+    et_file_tag_set_picture (destination, source->picture);
 
-    if (FileTagCur->title)
+    if (source->other)
     {
-        FileTag->title = g_strdup(FileTagCur->title);
-    }else
-    {
-        g_free(FileTag->title);
-        FileTag->title = NULL;
-    }
-
-    if (FileTagCur->artist)
-    {
-        FileTag->artist = g_strdup(FileTagCur->artist);
-    }else
-    {
-        g_free(FileTag->artist);
-        FileTag->artist = NULL;
-    }
-
-    if (FileTagCur->album_artist)
-    {
-        FileTag->album_artist = g_strdup(FileTagCur->album_artist);
-    }else
-    {
-        g_free(FileTag->album_artist);
-        FileTag->album_artist = NULL;
-    }
-
-    if (FileTagCur->album)
-    {
-        FileTag->album = g_strdup(FileTagCur->album);
-    }else
-    {
-        g_free(FileTag->album);
-        FileTag->album = NULL;
-    }
-
-    if (FileTagCur->disc_number)
-    {
-        FileTag->disc_number = g_strdup(FileTagCur->disc_number);
-    }else
-    {
-        g_free(FileTag->disc_number);
-        FileTag->disc_number = NULL;
-    }
-
-    if (FileTagCur->disc_total)
-    {
-        FileTag->disc_total = g_strdup (FileTagCur->disc_total);
+        et_file_tag_copy_other_into (destination, source);
     }
     else
     {
-        g_free (FileTag->disc_total);
-        FileTag->disc_total = NULL;
+        et_file_tag_free_other_field (destination);
     }
-
-    if (FileTagCur->year)
-    {
-        FileTag->year = g_strdup(FileTagCur->year);
-    }else
-    {
-        g_free(FileTag->year);
-        FileTag->year = NULL;
-    }
-
-    if (FileTagCur->track)
-    {
-        FileTag->track = g_strdup(FileTagCur->track);
-    }else
-    {
-        g_free(FileTag->track);
-        FileTag->track = NULL;
-    }
-
-    if (FileTagCur->track_total)
-    {
-        FileTag->track_total = g_strdup(FileTagCur->track_total);
-    }else
-    {
-        g_free(FileTag->track_total);
-        FileTag->track_total = NULL;
-    }
-
-    if (FileTagCur->genre)
-    {
-        FileTag->genre = g_strdup(FileTagCur->genre);
-    }else
-    {
-        g_free(FileTag->genre);
-        FileTag->genre = NULL;
-    }
-
-    if (FileTagCur->comment)
-    {
-        FileTag->comment = g_strdup(FileTagCur->comment);
-    }else
-    {
-        g_free(FileTag->comment);
-        FileTag->comment = NULL;
-    }
-
-    if (FileTagCur->composer)
-    {
-        FileTag->composer = g_strdup(FileTagCur->composer);
-    }else
-    {
-        g_free(FileTag->composer);
-        FileTag->composer = NULL;
-    }
-
-    if (FileTagCur->orig_artist)
-    {
-        FileTag->orig_artist = g_strdup(FileTagCur->orig_artist);
-    }else
-    {
-        g_free(FileTag->orig_artist);
-        FileTag->orig_artist = NULL;
-    }
-
-    if (FileTagCur->copyright)
-    {
-        FileTag->copyright = g_strdup(FileTagCur->copyright);
-    }else
-    {
-        g_free(FileTag->copyright);
-        FileTag->copyright = NULL;
-    }
-
-    if (FileTagCur->url)
-    {
-        FileTag->url = g_strdup(FileTagCur->url);
-    }else
-    {
-        g_free(FileTag->url);
-        FileTag->url = NULL;
-    }
-
-    if (FileTagCur->encoded_by)
-    {
-        FileTag->encoded_by = g_strdup(FileTagCur->encoded_by);
-    }else
-    {
-        g_free(FileTag->encoded_by);
-        FileTag->encoded_by = NULL;
-    }
-
-    et_file_tag_set_picture (FileTag, FileTagCur->picture);
-
-    if (FileTagCur->other)
-    {
-        ET_Copy_File_Tag_Item_Other_Field(ETFile,FileTag);
-    }else
-    {
-        ET_Free_File_Tag_Item_Other_Field (FileTag);
-    }
-
-    return TRUE;
 }
 
 /*
@@ -307,8 +140,8 @@ ET_Copy_File_Tag_Item (const ET_File *ETFile, File_Tag *FileTag)
  * Must be used only for the 'gchar *' components
  */
 static void
-ET_Set_Field_File_Tag_Item (gchar **FileTagField,
-                            const gchar *value)
+et_file_tag_set_field (gchar **FileTagField,
+                       const gchar *value)
 {
     g_return_if_fail (FileTagField != NULL);
 
@@ -333,7 +166,7 @@ et_file_tag_set_title (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->title, title);
+    et_file_tag_set_field (&file_tag->title, title);
 }
 
 void
@@ -342,7 +175,7 @@ et_file_tag_set_artist (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->artist, artist);
+    et_file_tag_set_field (&file_tag->artist, artist);
 }
 
 void
@@ -351,7 +184,7 @@ et_file_tag_set_album_artist (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->album_artist, album_artist);
+    et_file_tag_set_field (&file_tag->album_artist, album_artist);
 }
 
 void
@@ -360,7 +193,7 @@ et_file_tag_set_album (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->album, album);
+    et_file_tag_set_field (&file_tag->album, album);
 }
 
 void
@@ -369,7 +202,7 @@ et_file_tag_set_disc_number (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->disc_number, disc_number);
+    et_file_tag_set_field (&file_tag->disc_number, disc_number);
 }
 
 void
@@ -378,7 +211,7 @@ et_file_tag_set_disc_total (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->disc_total, disc_total);
+    et_file_tag_set_field (&file_tag->disc_total, disc_total);
 }
 
 void
@@ -387,7 +220,7 @@ et_file_tag_set_year (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->year, year);
+    et_file_tag_set_field (&file_tag->year, year);
 }
 
 void
@@ -396,7 +229,7 @@ et_file_tag_set_track_number (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->track, track_number);
+    et_file_tag_set_field (&file_tag->track, track_number);
 }
 
 void
@@ -405,7 +238,7 @@ et_file_tag_set_track_total (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->track_total, track_total);
+    et_file_tag_set_field (&file_tag->track_total, track_total);
 }
 
 void
@@ -414,7 +247,7 @@ et_file_tag_set_genre (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->genre, genre);
+    et_file_tag_set_field (&file_tag->genre, genre);
 }
 
 void
@@ -423,7 +256,7 @@ et_file_tag_set_comment (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->comment, comment);
+    et_file_tag_set_field (&file_tag->comment, comment);
 }
 
 void
@@ -432,7 +265,7 @@ et_file_tag_set_composer (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->composer, composer);
+    et_file_tag_set_field (&file_tag->composer, composer);
 }
 
 void
@@ -441,7 +274,7 @@ et_file_tag_set_orig_artist (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->orig_artist, orig_artist);
+    et_file_tag_set_field (&file_tag->orig_artist, orig_artist);
 }
 
 void
@@ -450,7 +283,7 @@ et_file_tag_set_copyright (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->copyright, copyright);
+    et_file_tag_set_field (&file_tag->copyright, copyright);
 }
 
 void
@@ -459,7 +292,7 @@ et_file_tag_set_url (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->url, url);
+    et_file_tag_set_field (&file_tag->url, url);
 }
 
 void
@@ -468,7 +301,7 @@ et_file_tag_set_encoded_by (File_Tag *file_tag,
 {
     g_return_if_fail (file_tag != NULL);
 
-    ET_Set_Field_File_Tag_Item (&file_tag->encoded_by, encoded_by);
+    et_file_tag_set_field (&file_tag->encoded_by, encoded_by);
 }
 
 /*
@@ -503,7 +336,7 @@ et_file_tag_set_picture (File_Tag *file_tag,
  *  - if field is '' or NULL => will be removed
  */
 gboolean
-ET_Detect_Changes_Of_File_Tag (const File_Tag *FileTag1,
+et_file_tag_detect_difference (const File_Tag *FileTag1,
                                const File_Tag *FileTag2)
 {
     const EtPicture *pic1;
