@@ -226,6 +226,9 @@ write_playlist (EtPlaylistDialog *self, GFile *file, GError **error)
                         g_free (mask);
                         g_free (filename_generated_utf8);
                     }
+                    default:
+                        g_assert_not_reached ();
+                        break;
                 }
 
                 /* 3) Write the file path. */
@@ -345,6 +348,9 @@ write_playlist (EtPlaylistDialog *self, GFile *file, GError **error)
                     g_free (filename_generated_utf8);
                 }
                 break;
+                default:
+                    g_assert_not_reached ();
+                    break;
             }
 
             /* 3) Write the file path. */
@@ -433,7 +439,6 @@ write_button_clicked (EtPlaylistDialog *self)
     /* Build the playlist filename. */
     if (g_settings_get_boolean (MainSettings, "playlist-use-mask"))
     {
-        gchar *playlist_name;
         EtConvertSpaces convert_mode;
 
         if (!ETCore->ETFileList)
@@ -466,8 +471,11 @@ write_button_clicked (EtPlaylistDialog *self)
             case ET_CONVERT_SPACES_REMOVE:
                 Scan_Remove_Spaces (playlist_basename_utf8);
                 break;
+            /* FIXME: Check that this is intended. */
+            case ET_CONVERT_SPACES_NO_CHANGE:
             default:
                 g_assert_not_reached ();
+                break;
         }
     }else // PLAYLIST_USE_DIR_NAME
     {
