@@ -1141,71 +1141,6 @@ Check_DefaultPathToMp3 (EtPreferencesDialog *self)
     return FALSE;
 }
 
-/*
- * The character set conversion is used for ID3 tag. UTF-8 is used to display.
- *  - reading_character is converted to UTF-8
- *  - writing_character is converted from UTF-8
- */
-/*****************
-gint Check_CharacterSetTranslation (void)
-{
-    gchar *temp;
-    gchar *reading_character;
-    gchar *writing_character;
-
-    temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileReadingCharacterSetCombo));
-    reading_character = Charset_Get_Name_From_Title(temp);
-    g_free(temp);
-
-    temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileWritingCharacterSetCombo));
-    writing_character = Charset_Get_Name_From_Title(temp);
-    g_free(temp);
-
-    // Check conversion when reading file
-    if ( GTK_TOGGLE_BUTTON(UseNonStandardId3ReadingCharacterSet)->active
-    && (test_conversion_charset(reading_character,"UTF-8")!=TRUE) )
-    {
-        gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
-                                       "to '%s' is not supported"),reading_character,"UTF-8");
-        GtkWidget *msgbox = msg_box_new(_("Error"),
-                                        GTK_WINDOW(OptionsWindow),
-                                        NULL,
-                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        msg,
-                                        GTK_STOCK_DIALOG_ERROR,
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                        NULL);
-        gtk_dialog_run(GTK_DIALOG(msgbox));
-        gtk_widget_destroy(msgbox);
-        g_free(msg);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(UseNonStandardId3ReadingCharacterSet),FALSE);
-        return 0;
-    }
-    // Check conversion when writing file
-    if ( GTK_TOGGLE_BUTTON(UseNonStandardId3WritingCharacterSet)->active
-    && (test_conversion_charset("UTF-8",writing_character)!=TRUE) )
-    {
-        gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
-                                       "to '%s' is not supported"),"UTF-8",writing_character);
-        GtkWidget *msgbox = msg_box_new(_("Error"),
-                                        GTK_WINDOW(OptionsWindow),
-                                        NULL,
-                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        msg,
-                                        GTK_STOCK_DIALOG_ERROR,
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                        NULL);
-        gtk_dialog_run(GTK_DIALOG(msgbox));
-        gtk_widget_destroy(msgbox);
-        g_free(msg);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(UseNonStandardId3WritingCharacterSet),FALSE);
-        return 0;
-    }
-
-    return 1;
-}
-*************/
-
 static gboolean
 Check_Config (EtPreferencesDialog *self)
 {
