@@ -18,15 +18,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <errno.h>
-#include <unistd.h>
 
 #include "easytag.h"
 #include "ape_tag.h"
@@ -89,6 +86,14 @@ ape_tag_read_file_tag (GFile *file,
     if (FileTag->artist == NULL)
         FileTag->artist = Try_To_Validate_Utf8_String(string);
 
+    /* Album artist. */
+    string = apefrm_getstr (ape_cnt, APE_TAG_FIELD_ALBUMARTIST);
+
+    if (FileTag->album_artist == NULL)
+    {
+        FileTag->album_artist = Try_To_Validate_Utf8_String (string);
+    }
+
     /*********
      * Album *
      *********/
@@ -252,6 +257,17 @@ ape_tag_write_file_tag (const ET_File *ETFile,
     else
         apefrm_remove(ape_mem,APE_TAG_FIELD_ARTIST);
 
+    /* Album artist. */
+    if (FileTag->album_artist && g_utf8_strlen (FileTag->album_artist, -1) > 0)
+    {
+        apefrm_add (ape_mem, 0, APE_TAG_FIELD_ALBUMARTIST,
+                    FileTag->album_artist);
+    }
+    else
+    {
+        apefrm_remove (ape_mem, APE_TAG_FIELD_ALBUMARTIST);
+    }
+
     /*********
      * Album *
      *********/
