@@ -89,9 +89,15 @@ gchar *
 et_id3tag_get_tpos_from_file_tag (const File_Tag *FileTag)
 {
     GString *gstring;
-    gchar *p;
+    const gchar *p;
 
     gstring = g_string_new ("");
+
+    if (!FileTag->disc_number)
+    {
+        return g_string_free (gstring, FALSE);
+    }
+
     p = FileTag->disc_number;
 
     while (*p)
@@ -194,23 +200,23 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
     {
         GtkWidget *msgdialog;
         gchar *basename;
-        gchar *basename_utf8;
+        gchar *utf8_basename;
 
         basename = g_file_get_basename (file);
-        basename_utf8 = filename_to_display (basename);
+        utf8_basename = filename_to_display (basename);
 
         msgdialog = gtk_message_dialog_new (GTK_WINDOW (MainWindow),
                                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             _("As the following corrupted file ‘%s’ will cause an error in id3lib, it will not be processed"),
-                                            basename_utf8);
+                                            utf8_basename);
         gtk_window_set_title (GTK_WINDOW (msgdialog), _("Corrupted file"));
 
         gtk_dialog_run (GTK_DIALOG (msgdialog));
         gtk_widget_destroy (msgdialog);
         g_free (basename);
-        g_free (basename_utf8);
+        g_free (utf8_basename);
         g_object_unref (file);
         return FALSE;
     }
@@ -509,6 +515,7 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
                     ID3Field_SetASCII (id3_field, "GIF");
                 }
                 break;
+            case PICTURE_FORMAT_UNKNOWN:
             default:
                 break;
         }
@@ -559,7 +566,7 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
         // Delete the APE tag (create a dummy ETFile for the Ape_Tag_... function)
         ET_File   *ETFile_tmp    = ET_File_Item_New();
         File_Name *FileName_tmp  = ET_File_Name_Item_New();
-        File_Tag  *FileTag_tmp   = ET_File_Tag_Item_New();
+        File_Tag  *FileTag_tmp = et_file_tag_new();
         // Same file...
         FileName_tmp->value      = g_strdup(filename);
         FileName_tmp->value_utf8 = g_strdup(filename_utf8);  // Not necessary to fill 'value_ck'
@@ -654,9 +661,11 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
                     && g_settings_get_boolean (MainSettings,
                                                "id3v2-enable-unicode"))
                 {
-                    File_Tag  *FileTag_tmp = ET_File_Tag_Item_New();
+                    File_Tag  *FileTag_tmp = et_file_tag_new ();
+
                     if (id3tag_read_file_tag (file, FileTag_tmp, NULL) == TRUE
-                    &&  ET_Detect_Changes_Of_File_Tag(FileTag,FileTag_tmp) == TRUE)
+                        && et_file_tag_detect_difference (FileTag,
+                                                          FileTag_tmp) == TRUE)
                     {
                         GtkWidget *msgdialog;
 
@@ -679,7 +688,8 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
                         gtk_widget_destroy(msgdialog);
                         flag_id3lib_bugged = FALSE; // To display the message only one time
                     }
-                    ET_Free_File_Tag_Item(FileTag_tmp);
+
+                    et_file_tag_free (FileTag_tmp);
                 }
 
             }
@@ -980,15 +990,9 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
                 }
                 else if (ID3Field_IsEncodable (id3_field))
                 {
-                    gint id3v1v2_charset;
-                    const gchar *charset;
-
                     string = g_malloc0 (ID3V2_MAX_STRING_LEN + 1);
                     num_chars = ID3Field_GetASCII_1 (id3_field, string,
                                                      ID3V2_MAX_STRING_LEN, 0);
-                    id3v1v2_charset = g_settings_get_enum (MainSettings,
-                                                           "id3v1v2-charset");
-                    charset = et_charset_get_name_from_index (id3v1v2_charset);
                     string1 = convert_string (string, charset, "UTF-8", FALSE);
                     /* Override to a non-standard character encoding. */
                     goto out;
@@ -1028,6 +1032,8 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
                 string1 = convert_string_1(string,num_chars,"UTF-16BE","UTF-8",FALSE);
                 break;
 
+            case ID3TE_NONE:
+            case ID3TE_NUMENCODINGS:
             default:
                 string = g_malloc0 (4 * ID3V2_MAX_STRING_LEN + 1);
                 num_chars = ID3Field_GetASCII_1(id3_field,string,ID3V2_MAX_STRING_LEN,0);
@@ -1208,6 +1214,10 @@ Id3tag_Set_Field (const ID3Frame *id3_frame,
                 break;
 
 override:
+            case ID3TE_UTF16BE:
+            case ID3TE_UTF8:
+            case ID3TE_NUMENCODINGS:
+            case ID3TE_NONE:
             default:
             {
                 //string_converted = convert_string(string,"UTF-8",charset,TRUE);
