@@ -539,7 +539,7 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
         EtPicture *pic;
         gsize bytes_pos, mimelen, desclen;
         guchar *decoded_ustr;
-        GBytes *bytes;
+        GBytes *bytes = NULL;
         EtPictureType type;
         gchar *description;
         GBytes *pic_bytes;
@@ -548,29 +548,89 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
 
         /* Decode picture data. */
         decoded_ustr = g_base64_decode (string, &decoded_size);
+
+        /* Check that the comment decoded to a long enough string to hold the
+         * whole structure (8 fields of 4 bytes each). */
+        if (decoded_size < 8 * 4)
+        {
+            g_free (decoded_ustr);
+            goto invalid_picture;
+        }
+
         bytes = g_bytes_new_take (decoded_ustr, decoded_size);
 
         /* Reading picture type. */
         type = read_guint32_from_byte (decoded_ustr, 0);
         bytes_pos = 4;
 
+        /* TODO: Check that there is a maximum of 1 of each of
+         * ET_PICTURE_TYPE_FILE_ICON and ET_PICTURE_TYPE_OTHER_FILE_ICON types
+         * in the file. */
+        if (type >= ET_PICTURE_TYPE_UNDEFINED)
+        {
+            goto invalid_picture;
+        }
+
         /* Reading MIME data. */
         mimelen = read_guint32_from_byte (decoded_ustr, bytes_pos);
-        bytes_pos = 8 + mimelen;
+        bytes_pos += 4;
+
+        if (mimelen > decoded_size - bytes_pos - (6 * 4))
+        {
+            goto invalid_picture;
+        }
+
+        /* Check for a valid MIME type. */
+        if (mimelen > 0)
+        {
+            const gchar *mime;
+
+            mime = (const gchar *)&decoded_ustr[bytes_pos];
+
+            /* TODO: Check for "-->" when adding linked image support. */
+            if (strncmp (mime, "image/", mimelen) != 0
+                && strncmp (mime, "image/png", mimelen) != 0
+                && strncmp (mime, "image/jpeg", mimelen) != 0)
+            {
+                gchar *mime_str;
+
+                mime_str = g_strndup (mime, mimelen);
+                g_debug ("Invalid Vorbis comment image MIME type: %s",
+                         mime_str);
+
+                g_free (mime_str);
+                goto invalid_picture;
+            }
+        }
+
+        /* Skip over the MIME type, as gdk-pixbuf does not use it. */
+        bytes_pos += mimelen;
 
         /* Reading description */
         desclen = read_guint32_from_byte (decoded_ustr, bytes_pos);
         bytes_pos += 4;
 
+        if (desclen > decoded_size - bytes_pos - (5 * 4))
+        {
+            goto invalid_picture;
+        }
+
         description = g_strndup ((const gchar *)&decoded_ustr[bytes_pos],
                                  desclen);
 
+        /* Skip the width, height, color depth and number-of-colors fields. */
         bytes_pos += desclen + 16;
 
         /* Reading picture size */
         data_size = read_guint32_from_byte (decoded_ustr, bytes_pos);
         bytes_pos += 4;
 
+        if (data_size > decoded_size - bytes_pos)
+        {
+            g_free (description);
+            goto invalid_picture;
+        }
+
         /* Read only the image data into a new GBytes. */
         pic_bytes = g_bytes_new_from_bytes (bytes, bytes_pos, data_size);
 
@@ -592,6 +652,14 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
 
         /* pic->bytes still holds a ref on the decoded data. */
         g_bytes_unref (bytes);
+        continue;
+
+invalid_picture:
+        /* Mark the file as modified, so that the invalid field is removed upon
+         * saving. */
+        FileTag->saved = FALSE;
+
+        g_bytes_unref (bytes);
     }
 
     /***************************
@@ -936,19 +1004,21 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
         if (format != PICTURE_FORMAT_PNG && format != PICTURE_FORMAT_JPEG)
         {
             GdkPixbufLoader *loader;
-            gconstpointer data;
-            gsize data_size;
-            GError *error = NULL;
+            gconstpointer old_data;
+            gsize old_data_size;
+            GError *loader_error = NULL;
 
             loader = gdk_pixbuf_loader_new ();
 
-            data = g_bytes_get_data (pic->bytes, &data_size);
+            old_data = g_bytes_get_data (pic->bytes, &old_data_size);
 
             /* TODO: Use gdk_pixbuf_loader_write_bytes() */
-            if (!gdk_pixbuf_loader_write (loader, data, data_size, &error))
+            if (!gdk_pixbuf_loader_write (loader, old_data, old_data_size,
+                                          &loader_error))
             {
-                g_debug ("Error parsing image data: %s", error->message);
-                g_error_free (error);
+                g_debug ("Error parsing image data: %s",
+                         loader_error->message);
+                g_error_free (loader_error);
                 g_object_unref (loader);
                 continue;
             }
@@ -958,11 +1028,11 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
                 gchar *buffer;
                 gsize buffer_size;
 
-                if (!gdk_pixbuf_loader_close (loader, &error))
+                if (!gdk_pixbuf_loader_close (loader, &loader_error))
                 {
                     g_debug ("Error parsing image data: %s",
-                             error->message);
-                    g_error_free (error);
+                             loader_error->message);
+                    g_error_free (loader_error);
                     g_object_unref (loader);
                     continue;
                 }
@@ -981,11 +1051,11 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
                 /* Always convert to PNG. */
                 if (!gdk_pixbuf_save_to_buffer (pixbuf, &buffer,
                                                 &buffer_size, "png",
-                                                &error, NULL))
+                                                &loader_error, NULL))
                 {
                     g_debug ("Error while converting image to PNG: %s",
-                             error->message);
-                    g_error_free (error);
+                             loader_error->message);
+                    g_error_free (loader_error);
                     g_object_unref (pixbuf);
                     continue;
                 }
