@@ -526,6 +526,7 @@ vcedit_open (EtOggState *state,
             headerpackets = 2;
 #endif
             break;
+        case ET_OGG_KIND_UNKNOWN:
         default:
             g_assert_not_reached ();
             break;
@@ -577,6 +578,9 @@ vcedit_open (EtOggState *state,
                                     state->bookbuf = g_memdup (header->packet,
                                                                header->bytes);
                                     break;
+                                default:
+                                    g_assert_not_reached ();
+                                    break;
                             }
                             break;
                         case ET_OGG_KIND_SPEEX:
@@ -620,8 +624,13 @@ vcedit_open (EtOggState *state,
                                                  "Ogg Opus tags do not follow the specification");
                                     goto err;
                                     break;
+                                default:
+                                    g_assert_not_reached ();
+                                    break;
                             }
+                            break;
 #endif
+                        case ET_OGG_KIND_UNKNOWN:
                         default:
                             g_assert_not_reached ();
                             break;
@@ -819,9 +828,7 @@ vcedit_write (EtOggState *state,
         {
             if (state->oggtype == ET_OGG_KIND_VORBIS)
             {
-                int size;
-                size = _blocksize(state, &op);
-                granpos += size;
+                granpos += _blocksize (state, &op);
             }
 #ifdef ENABLE_OPUS
             else
